==> haskell-hls-graph-2.0.0.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.0.0.0
visibility:           public
id:                   hls-graph-2.0.0.0-A4Md4H78vLU6kij9Pjl9FS
key:                  hls-graph-2.0.0.0-A4Md4H78vLU6kij9Pjl9FS
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  eae2fd8fc641468a3476440896668264
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-graph-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-graph-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-graph-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.0.0.0-A4Md4H78vLU6kij9Pjl9FS
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK filepath-1.4.2.2
    focus-1.0.3.2-3vZUDOF2BhE1UWMh8VQwoQ
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    js-dgtable-0.5.2-GJOZPjRBXVeCze8bD7YdfT
    js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
    js-jquery-3.3.1-6uLgCbeynTzFavx7nfaaFK
    list-t-1.0.5.5-JRNLt6jCPTeGozvl94ZB6L stm-2.5.1.0
    stm-containers-1.2.1.1-C85SUlHyrad2f0hZU7vbpJ text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-graph-2.0.0.0-27-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-graph.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-graph
version:              2.0.0.0
visibility:           public
id:                   hls-graph-2.0.0.0-7UT0IJRRpMZEeEYXNLfc4p
key:                  hls-graph-2.0.0.0-7UT0IJRRpMZEeEYXNLfc4p
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           The Haskell IDE Team
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Haskell Language Server internal graph API
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/hls-graph#readme>

category:             Development
abi:                  7b51adaaa103d7ff194d78b1621e7834
exposed:              True
exposed-modules:
    Control.Concurrent.STM.Stats Development.IDE.Graph
    Development.IDE.Graph.Classes Development.IDE.Graph.Database
    Development.IDE.Graph.Internal.Action
    Development.IDE.Graph.Internal.Database
    Development.IDE.Graph.Internal.Options
    Development.IDE.Graph.Internal.Paths
    Development.IDE.Graph.Internal.Profile
    Development.IDE.Graph.Internal.Rules
    Development.IDE.Graph.Internal.Types Development.IDE.Graph.KeyMap
    Development.IDE.Graph.KeySet Development.IDE.Graph.Rule
    Paths_hls_graph

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-graph-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-graph-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-graph-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-graph
hs-libraries:         HShls-graph-2.0.0.0-7UT0IJRRpMZEeEYXNLfc4p
depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge
    async-2.2.5-HIvtQdOwlf5Hsyin6u1n7Q base-4.17.2.1
    bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.0
    directory-1.3.7.1 exceptions-0.10.5
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK filepath-1.4.2.2
    focus-1.0.3.2-3vZUDOF2BhE1UWMh8VQwoQ
    hashable-1.4.4.0-nWtkxUvx9i9tMRJKCZgnw
    js-dgtable-0.5.2-GJOZPjRBXVeCze8bD7YdfT
    js-flot-0.8.3-IKtJvuN3TOl6yoqyRfRs9e
    js-jquery-3.3.1-JUdLsxH0DhK5bfWVMDm29
    list-t-1.0.5.5-JRNLt6jCPTeGozvl94ZB6L stm-2.5.1.0
    stm-containers-1.2.1.1-C85SUlHyrad2f0hZU7vbpJ text-2.0.2
    time-1.12.2 transformers-0.5.6.2
    unliftio-0.2.25.1-LfkN9oBuVsC1PSAv8s4AS5
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:   /usr/share/doc/haskell-hls-graph/html/hls-graph.haddock
haddock-html:         /usr/share/doc/haskell-hls-graph/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
